#
# spec file for package zbar
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010 Carlos Goncalves <cgoncalves@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname lib%{name}%{sover}
Name:           zbar
Version:        0.23.93
Release:        2.7
Summary:        Bar code reader
License:        LGPL-2.0-or-later
URL:            https://github.com/mchehab/zbar
Source0:        https://linuxtv.org/downloads/%{name}/%{name}-%{version}.tar.bz2
Source98:       baselibs.conf
# https://github.com/mchehab/zbar/issues/277
Patch0:         https://github.com/mchehab/zbar/commit/368571ffa1a0f6cc41f708dd0d27f9b6e9409df8.patch#/zbar-pkgconfig.patch
# https://github.com/mchehab/zbar/issues/277
Patch1:         https://github.com/mchehab/zbar/commit/a549566ea11eb03622bd4458a1728ffe3f589163.patch#/zbar-configure.patch
BuildRequires:  automake
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  xmlto
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xv)
%lang_package

%description
ZBar reads bar codes from various sources, such as video streams,
image files and raw intensity sensors. It supports many symbologies
(types of bar codes) including EAN-13/UPC-A, UPC-E, EAN-8, Code 128,
Code 39, Interleaved 2 of 5 and QR Code.

It can be used through the standalone GUI and command-line programs,
or integrated by other programs through a library.

%package -n %{libname}
Summary:        Bar code reading library

%description -n %{libname}
ZBar reads bar codes from various sources, such as video streams,
image files and raw intensity sensors. It supports many symbologies
(types of bar codes) including EAN-13/UPC-A, UPC-E, EAN-8, Code 128,
Code 39, Interleaved 2 of 5 and QR Code.

This package provides the ZBar library.

%package -n lib%{name}-devel
Summary:        Development environment for the ZBar library
Requires:       %{libname} = %{version}

%description -n lib%{name}-devel
This package contains all necessary include files, libraries,
configuration files and development tools needed to compile and link
applications using the zbar library.

%package -n lib%{name}qt0
Summary:        ZBar Qt bindings

%description -n lib%{name}qt0
This package provides ZBar Qt bindings.

%package -n lib%{name}qt-devel
Summary:        Development environment for the ZBar Qt bindings library
Requires:       lib%{name}-devel = %{version}
Requires:       lib%{name}qt0 = %{version}

%description -n lib%{name}qt-devel
This package contains all necessary include files, libraries,
configuration files and development tools needed to compile and link
applications using the zbar-qt library.

%package -n python3-zbar
Summary:        Python3 module for ZBar

%description -n python3-zbar
This package contains the module to use ZBar from python3.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
  --docdir=%{_docdir}/%{name} \
  --disable-static \
  --without-java \
  --with-python=python3 \
  --without-gtk
%make_build

%install
%make_install
find %{buildroot} -name "*.la"  -or -name "*.a" | xargs rm -f
rm -rf %{buildroot}%{_datadir}/doc/zbar-%{version}/
rm -f %{buildroot}%{_docdir}/zbar/{COPYING,LICENSE.md,INSTALL.md}

%find_lang %{name}
# Lets wait for review first
rm -rf %{buildroot}%{_sysconfdir}/dbus-1/system.d/org.linuxtv.Zbar.conf

%ldconfig_scriptlets -n %{libname}
%ldconfig_scriptlets -n libzbarqt0

%files
%license COPYING LICENSE.md
%{_defaultdocdir}/%{name}/
%{_bindir}/zbarimg
%{_bindir}/zbarcam
%{_bindir}/zbarcam-qt
%{_mandir}/man1/*

%files lang -f %{name}.lang

%files -n %{libname}
%{_libdir}/libzbar.so.%{sover}*

%files -n lib%{name}-devel
%doc HACKING.md TODO.md
%dir %{_includedir}/%{name}
%{_includedir}/zbar.h
%{_includedir}/zbar/Exception.h
%{_includedir}/zbar/Symbol.h
%{_includedir}/zbar/Image.h
%{_includedir}/zbar/Scanner.h
%{_includedir}/zbar/Decoder.h
%{_includedir}/zbar/ImageScanner.h
%{_includedir}/zbar/Video.h
%{_includedir}/zbar/Window.h
%{_includedir}/zbar/Processor.h
%{_libdir}/libzbar.so
%{_libdir}/pkgconfig/zbar.pc

%files -n lib%{name}qt0
%{_libdir}/libzbarqt.so.%{sover}*

%files -n lib%{name}qt-devel
%{_includedir}/%{name}/QZBar*.h
%{_libdir}/libzbarqt.so
%{_libdir}/pkgconfig/zbar-qt.pc

%files -n python3-zbar
%{python3_sitearch}/zbar.so

%changelog
* Thu Jan 25 2024 Martin Pluskal <mpluskal@suse.com>
- Fix building for Leap
* Mon Jan 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.23.93:
  * Set a better dpi resolution when parsing PDF files
  * Fix memory recycle bug of empty symbols
  * Fix compilation with python 3.11 and 3.12
  * CVE-2023-40889: Fix array out-of-bounds access
  * Stop ignoring non-binary entries that follow binary ones
  * Increase allocated buffer memory for symbols
  * barcodetest.py: fix error code print logic
  * convert: Crash fixing while using camera
  * Add some pod information for additional functions
  * perl skip more tests if DISPLAY not set and set prereqs in Makefile.PL
  * Fixes rt.cpan.org 122061 - test fails when DISPLAY not set
  * Update Barcode::ZBar
  * isaac: ensure proper order of parsing expression
  * Enforce x11 backend even on wayland
  * zbarimg: add the --polygon option
  * xml output: Add polygon containing code bar.
  * configure.ac: drop support for Qt4 and prepare for Qt6 support
  * win: fix compiling error in Visual studio
  * Enforce a coding style
  * configure.ac: fix some issues with gtk parameter
  * zbargtk: fix version check macros
  * zbar: Address some header issues
  * zbar, test: fix compilation issues with FreeBSD
  * zbar: Function stdcall declaration issue.
  * symbol: make it compatible with MSC
  * zbar: change the code to make it c90 standard compatible
  * test: fix decode test
- Drop upstreamed patches:
  * zbar-CVE-2023-40889.patch
  * zbar-CVE-2023-40890.patch
  * py311.patch
- Add patch to fix build see gh#mchehab/zbar#277:
  * zbar-configure.patch
  * zbar-pkgconfig.patch
* Wed Dec 13 2023 Michael Vetter <mvetter@suse.com>
- security update:
  * CVE-2023-40889 [bsc#1214770]
    Fix heap based buffer overflow in qr_reader_match_centers()
    + zbar-CVE-2023-40889.patch
  * CVE-2023-40890 [bsc#1214771]
    Fix stack based buffer overflow in lookup_sequence()
    + zbar-CVE-2023-40890.patch
* Tue Jun 20 2023 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Split lang subpackage
* Fri Apr 28 2023 Dirk Müller <dmueller@suse.com>
- add py311.patch to fix build against python 3.11
* Mon Dec 19 2022 pgajdos@suse.com
- ImageMagick instead of GraphicsMagick
* Wed Feb 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.23.90
  * Fixed several issues with configure.ac, making it auto-detect
    most things, when possible
  * Fixed some build issues
  * Make it compatible with Python 3.9
  * Fixed some Python 3.9 and Qt5 warnings
  * Typo fixes
  * Several fixes at zbarcam
  * zbarimg: fix stderr output when symbols are found
- Drop 0001-Create-correct-pkconfig-file-for-zbar-qt5.patch and
  0002-get-rid-of-gettext_h.patch (merged upstream)
- Enable python3 module
* Thu Jan 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Apply patch0 unconditionally and fix build on Leap
* Wed Nov 18 2020 Wang Jun <jgwang@suse.com>
- Update to version 0.23.1
  * Add i18n translation support and add a pt_BR translation
  * Change default to autodetect python and gtk versions
  * Some documentation updates
  * Add support for binary data extraction
  * Add support for raw decoding without charset conversions
  * Add one shot scanning mode
  * Fix help messages
  * Fix some makefile issues
  * Fix error detection in video4linux read
  * Fix pkgconfig for zbar-qt5
  * Fix a double-free condition
- Add 0002-get-rid-of-gettext_h.patch
* Sun Oct 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove references to Qt4 from zbar-qt pkgconfig file (#62),
  add 0001-Create-correct-pkconfig-file-for-zbar-qt5.patch
* Sat Jul  6 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.23:
  * Support for Gtk3 (backward support with Gtk2 will be maintained.
  * Support for Python 3 (backward support with Python2 will be maintained);
  * Support for ZBar Gtk GObject Introspection (GIR). That allows using ZBar
    Gtk3 widgets on any language that it is compatible with GIR, including
    python 2 and python 3.
- Switch from ImageMagick to GraphicsMagick, the latter has significantly
  less build dependencies. As it is only used by the zbarimg tool to
  load images, this does not affect users of the zbar library.
- Update URL tag to point to the current upstream location
* Thu Mar 28 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.22:
  * zbarcam-qt: allow changing resolutions in real time
  * zbarcam-qt: better support ZBar options
  * zbarcam-qt: do several visual improvements
  * zbarcam-qt: make it remember the geometry
  * zbarcam-qt: allow show/hide control and options bars
  * zbarcam-qt: remember lastly used settings and camera controls
  * zbarcam-qt: allow changing ZBar decode options via GUI
  * Add API to allow get/set resolutions
  * img_scanner: add handler for color-inverted codes
  * img_scanner: fix get_config parameter validation
  * scan_video: improve logic to remove duplicated/invalid devnodes
  * symbol.c: fix symbol hash logic (prevents crash with QR options)
  * configure.ac: fix an error at libv4l2 package check
  * fix some typos
  * exit gracefully when decoding split QR codes
* Fri Mar  8 2019 olaf@aepfle.de
- Use gcc7 in SLE_12
* Fri Feb 15 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.21:
  * zbarcam-qt: allow selecting codes via GUI interface
  * When both enabled, ISBN-13 has precedence over ISBN-10
  * ZBar is now using Travis CI for continuous integration tests
  * Convert INSTALL and README to markdown and update them
  * Improve ZBar testing code and make easier to run the tests
  * Fix build with Clang
  * Add simple dbus IPC API to zbarcam.
  * zbarimg: display only the compiled symbologies
  * v4l2: make ZBar build and run on Kernels < 3.16
  * configure.ac: The pdf417 code is incomplete. Warn about that
  * Add Debian packaging and Travis CI configuration
  * Add barcode examples for different supported symbologies
  * Several improvements at the building system
  * Add support for SQ code symbology
  * v4l2: add fallback for systems without v4l2_ext_controls which field
  * v4l2: use device_caps instead of capabilities
  * v4l2: make v4l2_request_buffers() more generic
  * release video buffers after probing and request them again when needed
  * Ignore ENOTTY errors when calling VIDIOC_S_CROP
  * doc/Makefile.am.inc: clean html generated files
  * Add --disable-doc configure option to disable building docs
  * Fix function protoype to be compatible with recent libjpeg
  * Wrap logical not operations into parentheses
  * INSTALL: warn that autoconf should be called before configure
  * code128: fix error logic
  * convert: ensure that it will not use a freed value
  * zbar: use g_thread_new() instead of g_tread_create()
  * zbargtk: add a missing break
  * gtk/zbargtk: add a missing check if zbar->window is not null
- Remove accidentaly introduced build dependency on python2
- We no longer need to generate configure
- Make building more verbose
* Wed Jan 23 2019 info@paolostivanin.com
- Update Zbar to v0.20.1
  * switch from the old abandoned codebase to the new codebase
    maintained by linuxtv.org
  * improved v4l2 support
  * compatible with Qt5
  * various fixes
- Removed fix_build.patch
- Removed fix-gcc5.patch
- Removed zbar-Qt5.patch
- Removed fix-gcc8.patch
* Tue Apr 10 2018 mliska@suse.cz
- Add fix-gcc8.patch (boo#1088885).
* Wed Nov  1 2017 mpluskal@suse.com
- Drop python bindings and gtk support
- Cleanup with spec-cleaner
* Sat Aug  5 2017 aloisio@gmx.com
- Added zbar-Qt5.patch to build against Qt5
* Fri Feb  3 2017 jengelh@inai.de
- Compact and update descriptions
* Fri Feb  3 2017 dimstar@opensuse.org
- Properly packaeg %%_defaultdocdir: new rpm versions no longer
  implicitly add this to the packages.
* Fri Jul  1 2016 dimstar@opensuse.org
- Add baselibs.conf (boo#987287).
* Tue Jun 14 2016 jengelh@inai.de
- Ensure SONAME symlinks stay with the library
* Thu Jun  9 2016 dimstar@opensuse.org
- Add update.sh to the source list.
* Wed Jun  8 2016 dimstar@opensuse.org
- Cleanup specfile for inclusion into openSUSE:
  + Use upstream provided tarball.
  + The devel packages follow the library basename, not the shared
    library packaging name (not parallel installable).
  + Groups for SLPP packages is System/Libraries.
  + The various devel-packages are auto-depending on each other
    based on the .pc files.
  + Move autoreconf call to build phase.
  + Pass --disable-static to configure instead of deleting the
    static libs in the end again.
* Thu Feb 28 2013 opensuse@dstoecker.de
- update to current mercurial code
* Mon Aug  6 2012 opensuse@dstoecker.de
- fix build, update to recent mercurial revision from 2012-08-06
* Sat Nov 19 2011 opensuse@dstoecker.de
- fix build for openSUSE 12.1 (update to Mercurial version from 2011-11-19)
* Fri Apr  2 2010 cgoncalves@opensuse.org
- initial package (version 0.10)
